==> zio-aws-config_3-5.17.152.1-sources.jar: zio/aws/config/model/GetAggregateDiscoveredResourceCountsRequest.scala <==
package zio.aws.config.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.config.model.primitives.{
  NextToken,
  GroupByAPILimit,
  ConfigurationAggregatorName
}
import scala.jdk.CollectionConverters.*
final case class GetAggregateDiscoveredResourceCountsRequest(
    configurationAggregatorName: ConfigurationAggregatorName,
    filters: Option[zio.aws.config.model.ResourceCountFilters] = None,
    groupByKey: Option[zio.aws.config.model.ResourceCountGroupKey] = None,
    limit: Option[GroupByAPILimit] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest = {
    import GetAggregateDiscoveredResourceCountsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
      .builder()
      .configurationAggregatorName(
        ConfigurationAggregatorName.unwrap(
          configurationAggregatorName
        ): java.lang.String
      )
      .optionallyWith(filters.map(value => value.buildAwsValue()))(_.filters)
      .optionallyWith(groupByKey.map(value => value.unwrap))(_.groupByKey)
      .optionallyWith(
        limit.map(value => GroupByAPILimit.unwrap(value): Integer)
      )(_.limit)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest.ReadOnly =
    zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest
      .wrap(buildAwsValue())
}
object GetAggregateDiscoveredResourceCountsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest =
      zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest(
        configurationAggregatorName,
        filters.map(value => value.asEditable),
        groupByKey.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value)
      )
    def configurationAggregatorName: ConfigurationAggregatorName
    def filters: Option[zio.aws.config.model.ResourceCountFilters.ReadOnly]
    def groupByKey: Option[zio.aws.config.model.ResourceCountGroupKey]
    def limit: Option[GroupByAPILimit]
    def nextToken: Option[NextToken]
    def getConfigurationAggregatorName
        : ZIO[Any, Nothing, ConfigurationAggregatorName] =
      ZIO.succeed(configurationAggregatorName)
    def getFilters: ZIO[
      Any,
      AwsError,
      zio.aws.config.model.ResourceCountFilters.ReadOnly
    ] = AwsError.unwrapOptionField("filters", filters)
    def getGroupByKey
        : ZIO[Any, AwsError, zio.aws.config.model.ResourceCountGroupKey] =
      AwsError.unwrapOptionField("groupByKey", groupByKey)
    def getLimit: ZIO[Any, AwsError, GroupByAPILimit] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
  ) extends zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest.ReadOnly {
    override val configurationAggregatorName: ConfigurationAggregatorName =
      zio.aws.config.model.primitives
        .ConfigurationAggregatorName(impl.configurationAggregatorName())
    override val filters
        : Option[zio.aws.config.model.ResourceCountFilters.ReadOnly] = scala
      .Option(impl.filters())
      .map(value => zio.aws.config.model.ResourceCountFilters.wrap(value))
    override val groupByKey
        : Option[zio.aws.config.model.ResourceCountGroupKey] = scala
      .Option(impl.groupByKey())
      .map(value => zio.aws.config.model.ResourceCountGroupKey.wrap(value))
    override val limit: Option[GroupByAPILimit] = scala
      .Option(impl.limit())
      .map(value => zio.aws.config.model.primitives.GroupByAPILimit(value))
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.config.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
  ): zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-config_3-7.21.15.2-sources.jar: zio/aws/config/model/GetAggregateDiscoveredResourceCountsRequest.scala <==
package zio.aws.config.model
import zio.prelude.data.Optional
import zio.aws.config.model.primitives.{
  NextToken,
  GroupByAPILimit,
  ConfigurationAggregatorName
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class GetAggregateDiscoveredResourceCountsRequest(
    configurationAggregatorName: ConfigurationAggregatorName,
    filters: Optional[zio.aws.config.model.ResourceCountFilters] =
      Optional.Absent,
    groupByKey: Optional[zio.aws.config.model.ResourceCountGroupKey] =
      Optional.Absent,
    limit: Optional[GroupByAPILimit] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest = {
    import GetAggregateDiscoveredResourceCountsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
      .builder()
      .configurationAggregatorName(
        ConfigurationAggregatorName.unwrap(
          configurationAggregatorName
        ): java.lang.String
      )
      .optionallyWith(filters.map(value => value.buildAwsValue()))(_.filters)
      .optionallyWith(groupByKey.map(value => value.unwrap))(_.groupByKey)
      .optionallyWith(
        limit.map(value => GroupByAPILimit.unwrap(value): Integer)
      )(_.limit)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest.ReadOnly =
    zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest
      .wrap(buildAwsValue())
}
object GetAggregateDiscoveredResourceCountsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest =
      zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest(
        configurationAggregatorName,
        filters.map(value => value.asEditable),
        groupByKey.map(value => value),
        limit.map(value => value),
        nextToken.map(value => value)
      )
    def configurationAggregatorName: ConfigurationAggregatorName
    def filters: Optional[zio.aws.config.model.ResourceCountFilters.ReadOnly]
    def groupByKey: Optional[zio.aws.config.model.ResourceCountGroupKey]
    def limit: Optional[GroupByAPILimit]
    def nextToken: Optional[NextToken]
    def getConfigurationAggregatorName
        : ZIO[Any, Nothing, ConfigurationAggregatorName] =
      ZIO.succeed(configurationAggregatorName)
    def getFilters: ZIO[
      Any,
      AwsError,
      zio.aws.config.model.ResourceCountFilters.ReadOnly
    ] = AwsError.unwrapOptionField("filters", filters)
    def getGroupByKey
        : ZIO[Any, AwsError, zio.aws.config.model.ResourceCountGroupKey] =
      AwsError.unwrapOptionField("groupByKey", groupByKey)
    def getLimit: ZIO[Any, AwsError, GroupByAPILimit] =
      AwsError.unwrapOptionField("limit", limit)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
  ) extends zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest.ReadOnly {
    override val configurationAggregatorName: ConfigurationAggregatorName =
      zio.aws.config.model.primitives
        .ConfigurationAggregatorName(impl.configurationAggregatorName())
    override val filters
        : Optional[zio.aws.config.model.ResourceCountFilters.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value => zio.aws.config.model.ResourceCountFilters.wrap(value))
    override val groupByKey
        : Optional[zio.aws.config.model.ResourceCountGroupKey] =
      zio.aws.core.internal
        .optionalFromNullable(impl.groupByKey())
        .map(value => zio.aws.config.model.ResourceCountGroupKey.wrap(value))
    override val limit: Optional[GroupByAPILimit] = zio.aws.core.internal
      .optionalFromNullable(impl.limit())
      .map(value => zio.aws.config.model.primitives.GroupByAPILimit(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.config.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.config.model.GetAggregateDiscoveredResourceCountsRequest
  ): zio.aws.config.model.GetAggregateDiscoveredResourceCountsRequest.ReadOnly =
    new Wrapper(impl)
}
